pub struct Label {
octets: Bytes,
}Expand description
A label is just a sequence of octets, which are compared as case-insensitive ASCII. A label can be no longer than 63 octets.
Fields
octets: BytesPrivate to this module so constructing an invalid Label is
impossible.
Implementations